@@ -9,18 +9,22 @@ static const R_FortranMethodDef FortEntries[] = {
     {"cvpl",                 (DL_FUNC) &F77_SUB(cvpl),                 29},
     {"cvpl_logn",            (DL_FUNC) &F77_SUB(cvpl_logn),            29},
     {"cvpl_long",            (DL_FUNC) &F77_SUB(cvpl_long),            38},
+	{"cvplnl",            	(DL_FUNC) &F77_SUB(cvplnl),                45},
     {"frailpenal",           (DL_FUNC) &F77_SUB(frailpenal),           58},
     {"frailpred_sha_nor_mc", (DL_FUNC) &F77_SUB(frailpred_sha_nor_mc),  5},
     {"joint",                (DL_FUNC) &F77_SUB(joint),                65},
     {"joint_longi",          (DL_FUNC) &F77_SUB(joint_longi),          62},
+	{"jointlonginl",          (DL_FUNC) &F77_SUB(jointlonginl),	       62},
     {"joint_multiv",         (DL_FUNC) &F77_SUB(joint_multiv),         63},
+	{"longiuninl",         (DL_FUNC) &F77_SUB(longiuninl),             31},
     {"nested",               (DL_FUNC) &F77_SUB(nested),               57},
-    {"predict",              (DL_FUNC) &F77_SUB(predict),              43},
+    {"predict",              (DL_FUNC) &F77_SUB(predict),              44},
     {"predict_biv",          (DL_FUNC) &F77_SUB(predict_biv),          32},
-	{"predictfam",          (DL_FUNC) &F77_SUB(predictfam),          30},
+	{"predictfam",          (DL_FUNC) &F77_SUB(predictfam),            31},
     {"predict_logn_sha",     (DL_FUNC) &F77_SUB(predict_logn_sha),     15},
     {"predict_recurr_sha",   (DL_FUNC) &F77_SUB(predict_recurr_sha),   19},
     {"predict_tri",          (DL_FUNC) &F77_SUB(predict_tri),          38},
+	{"predicttrinl",	      (DL_FUNC) &F77_SUB(predicttrinl),  	   42},
     {"risque2",              (DL_FUNC) &F77_SUB(risque2),               6},
     {"survival_cpm",         (DL_FUNC) &F77_SUB(survival_cpm),          6},
     {"survival_cpm2",        (DL_FUNC) &F77_SUB(survival_cpm2),         6},
